@@ -6,14 +6,14 @@ Type annotations for es service type definitions.
 Usage::
 
     ```python
-    from mypy_boto3_es.type_defs import AcceptInboundCrossClusterSearchConnectionResponseTypeDef
+    from mypy_boto3_es.type_defs import AcceptInboundCrossClusterSearchConnectionRequestRequestTypeDef
 
-    data: AcceptInboundCrossClusterSearchConnectionResponseTypeDef = {...}
+    data: AcceptInboundCrossClusterSearchConnectionRequestRequestTypeDef = {...}
     ```
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List
+from typing import Any, Dict, List, Union
 
 from .literals import (
     AutoTuneDesiredStateType,
@@ -49,13 +49,16 @@ else:
 
 
 __all__ = (
+    "AcceptInboundCrossClusterSearchConnectionRequestRequestTypeDef",
     "AcceptInboundCrossClusterSearchConnectionResponseTypeDef",
     "AccessPoliciesStatusTypeDef",
+    "AddTagsRequestRequestTypeDef",
     "AdditionalLimitTypeDef",
     "AdvancedOptionsStatusTypeDef",
     "AdvancedSecurityOptionsInputTypeDef",
     "AdvancedSecurityOptionsStatusTypeDef",
     "AdvancedSecurityOptionsTypeDef",
+    "AssociatePackageRequestRequestTypeDef",
     "AssociatePackageResponseTypeDef",
     "AutoTuneDetailsTypeDef",
     "AutoTuneMaintenanceScheduleTypeDef",
@@ -65,29 +68,48 @@ __all__ = (
     "AutoTuneOptionsTypeDef",
     "AutoTuneStatusTypeDef",
     "AutoTuneTypeDef",
+    "CancelElasticsearchServiceSoftwareUpdateRequestRequestTypeDef",
     "CancelElasticsearchServiceSoftwareUpdateResponseTypeDef",
     "CognitoOptionsStatusTypeDef",
     "CognitoOptionsTypeDef",
     "ColdStorageOptionsTypeDef",
     "CompatibleVersionsMapTypeDef",
+    "CreateElasticsearchDomainRequestRequestTypeDef",
     "CreateElasticsearchDomainResponseTypeDef",
+    "CreateOutboundCrossClusterSearchConnectionRequestRequestTypeDef",
     "CreateOutboundCrossClusterSearchConnectionResponseTypeDef",
+    "CreatePackageRequestRequestTypeDef",
     "CreatePackageResponseTypeDef",
+    "DeleteElasticsearchDomainRequestRequestTypeDef",
     "DeleteElasticsearchDomainResponseTypeDef",
+    "DeleteInboundCrossClusterSearchConnectionRequestRequestTypeDef",
     "DeleteInboundCrossClusterSearchConnectionResponseTypeDef",
+    "DeleteOutboundCrossClusterSearchConnectionRequestRequestTypeDef",
     "DeleteOutboundCrossClusterSearchConnectionResponseTypeDef",
+    "DeletePackageRequestRequestTypeDef",
     "DeletePackageResponseTypeDef",
+    "DescribeDomainAutoTunesRequestRequestTypeDef",
     "DescribeDomainAutoTunesResponseTypeDef",
+    "DescribeElasticsearchDomainConfigRequestRequestTypeDef",
     "DescribeElasticsearchDomainConfigResponseTypeDef",
+    "DescribeElasticsearchDomainRequestRequestTypeDef",
     "DescribeElasticsearchDomainResponseTypeDef",
+    "DescribeElasticsearchDomainsRequestRequestTypeDef",
     "DescribeElasticsearchDomainsResponseTypeDef",
+    "DescribeElasticsearchInstanceTypeLimitsRequestRequestTypeDef",
     "DescribeElasticsearchInstanceTypeLimitsResponseTypeDef",
+    "DescribeInboundCrossClusterSearchConnectionsRequestRequestTypeDef",
     "DescribeInboundCrossClusterSearchConnectionsResponseTypeDef",
+    "DescribeOutboundCrossClusterSearchConnectionsRequestRequestTypeDef",
     "DescribeOutboundCrossClusterSearchConnectionsResponseTypeDef",
     "DescribePackagesFilterTypeDef",
+    "DescribePackagesRequestRequestTypeDef",
     "DescribePackagesResponseTypeDef",
+    "DescribeReservedElasticsearchInstanceOfferingsRequestRequestTypeDef",
     "DescribeReservedElasticsearchInstanceOfferingsResponseTypeDef",
+    "DescribeReservedElasticsearchInstancesRequestRequestTypeDef",
     "DescribeReservedElasticsearchInstancesResponseTypeDef",
+    "DissociatePackageRequestRequestTypeDef",
     "DissociatePackageResponseTypeDef",
     "DomainEndpointOptionsStatusTypeDef",
     "DomainEndpointOptionsTypeDef",
@@ -106,9 +128,13 @@ __all__ = (
     "EncryptionAtRestOptionsTypeDef",
     "ErrorDetailsTypeDef",
     "FilterTypeDef",
+    "GetCompatibleElasticsearchVersionsRequestRequestTypeDef",
     "GetCompatibleElasticsearchVersionsResponseTypeDef",
+    "GetPackageVersionHistoryRequestRequestTypeDef",
     "GetPackageVersionHistoryResponseTypeDef",
+    "GetUpgradeHistoryRequestRequestTypeDef",
     "GetUpgradeHistoryResponseTypeDef",
+    "GetUpgradeStatusRequestRequestTypeDef",
     "GetUpgradeStatusResponseTypeDef",
     "InboundCrossClusterSearchConnectionStatusTypeDef",
     "InboundCrossClusterSearchConnectionTypeDef",
@@ -116,10 +142,15 @@ __all__ = (
     "InstanceLimitsTypeDef",
     "LimitsTypeDef",
     "ListDomainNamesResponseTypeDef",
+    "ListDomainsForPackageRequestRequestTypeDef",
     "ListDomainsForPackageResponseTypeDef",
+    "ListElasticsearchInstanceTypesRequestRequestTypeDef",
     "ListElasticsearchInstanceTypesResponseTypeDef",
+    "ListElasticsearchVersionsRequestRequestTypeDef",
     "ListElasticsearchVersionsResponseTypeDef",
+    "ListPackagesForDomainRequestRequestTypeDef",
     "ListPackagesForDomainResponseTypeDef",
+    "ListTagsRequestRequestTypeDef",
     "ListTagsResponseTypeDef",
     "LogPublishingOptionTypeDef",
     "LogPublishingOptionsStatusTypeDef",
@@ -133,9 +164,12 @@ __all__ = (
     "PackageSourceTypeDef",
     "PackageVersionHistoryTypeDef",
     "PaginatorConfigTypeDef",
+    "PurchaseReservedElasticsearchInstanceOfferingRequestRequestTypeDef",
     "PurchaseReservedElasticsearchInstanceOfferingResponseTypeDef",
     "RecurringChargeTypeDef",
+    "RejectInboundCrossClusterSearchConnectionRequestRequestTypeDef",
     "RejectInboundCrossClusterSearchConnectionResponseTypeDef",
+    "RemoveTagsRequestRequestTypeDef",
     "ReservedElasticsearchInstanceOfferingTypeDef",
     "ReservedElasticsearchInstanceTypeDef",
     "ResponseMetadataTypeDef",
@@ -146,12 +180,16 @@ __all__ = (
     "ServiceSoftwareOptionsTypeDef",
     "SnapshotOptionsStatusTypeDef",
     "SnapshotOptionsTypeDef",
+    "StartElasticsearchServiceSoftwareUpdateRequestRequestTypeDef",
     "StartElasticsearchServiceSoftwareUpdateResponseTypeDef",
     "StorageTypeLimitTypeDef",
     "StorageTypeTypeDef",
     "TagTypeDef",
+    "UpdateElasticsearchDomainConfigRequestRequestTypeDef",
     "UpdateElasticsearchDomainConfigResponseTypeDef",
+    "UpdatePackageRequestRequestTypeDef",
     "UpdatePackageResponseTypeDef",
+    "UpgradeElasticsearchDomainRequestRequestTypeDef",
     "UpgradeElasticsearchDomainResponseTypeDef",
     "UpgradeHistoryTypeDef",
     "UpgradeStepItemTypeDef",
@@ -161,12 +199,19 @@ __all__ = (
     "ZoneAwarenessConfigTypeDef",
 )
 
+AcceptInboundCrossClusterSearchConnectionRequestRequestTypeDef = TypedDict(
+    "AcceptInboundCrossClusterSearchConnectionRequestRequestTypeDef",
+    {
+        "CrossClusterSearchConnectionId": str,
+    },
+)
+
 AcceptInboundCrossClusterSearchConnectionResponseTypeDef = TypedDict(
     "AcceptInboundCrossClusterSearchConnectionResponseTypeDef",
     {
         "CrossClusterSearchConnection": "InboundCrossClusterSearchConnectionTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 AccessPoliciesStatusTypeDef = TypedDict(
@@ -177,6 +222,14 @@ AccessPoliciesStatusTypeDef = TypedDict(
     },
 )
 
+AddTagsRequestRequestTypeDef = TypedDict(
+    "AddTagsRequestRequestTypeDef",
+    {
+        "ARN": str,
+        "TagList": List["TagTypeDef"],
+    },
+)
+
 AdditionalLimitTypeDef = TypedDict(
     "AdditionalLimitTypeDef",
     {
@@ -223,12 +276,20 @@ AdvancedSecurityOptionsTypeDef = TypedDict(
     total=False,
 )
 
+AssociatePackageRequestRequestTypeDef = TypedDict(
+    "AssociatePackageRequestRequestTypeDef",
+    {
+        "PackageID": str,
+        "DomainName": str,
+    },
+)
+
 AssociatePackageResponseTypeDef = TypedDict(
     "AssociatePackageResponseTypeDef",
     {
         "DomainPackageDetails": "DomainPackageDetailsTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 AutoTuneDetailsTypeDef = TypedDict(
@@ -242,7 +303,7 @@ AutoTuneDetailsTypeDef = TypedDict(
 AutoTuneMaintenanceScheduleTypeDef = TypedDict(
     "AutoTuneMaintenanceScheduleTypeDef",
     {
-        "StartAt": datetime,
+        "StartAt": Union[datetime, str],
         "Duration": "DurationTypeDef",
         "CronExpressionForRecurrence": str,
     },
@@ -263,8 +324,8 @@ AutoTuneOptionsOutputTypeDef = TypedDict(
     {
         "State": AutoTuneStateType,
         "ErrorMessage": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
+    total=False,
 )
 
 AutoTuneOptionsStatusTypeDef = TypedDict(
@@ -318,12 +379,19 @@ AutoTuneTypeDef = TypedDict(
     total=False,
 )
 
+CancelElasticsearchServiceSoftwareUpdateRequestRequestTypeDef = TypedDict(
+    "CancelElasticsearchServiceSoftwareUpdateRequestRequestTypeDef",
+    {
+        "DomainName": str,
+    },
+)
+
 CancelElasticsearchServiceSoftwareUpdateResponseTypeDef = TypedDict(
     "CancelElasticsearchServiceSoftwareUpdateResponseTypeDef",
     {
         "ServiceSoftwareOptions": "ServiceSoftwareOptionsTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 CognitoOptionsStatusTypeDef = TypedDict(
@@ -361,12 +429,57 @@ CompatibleVersionsMapTypeDef = TypedDict(
     total=False,
 )
 
+_RequiredCreateElasticsearchDomainRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateElasticsearchDomainRequestRequestTypeDef",
+    {
+        "DomainName": str,
+    },
+)
+_OptionalCreateElasticsearchDomainRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateElasticsearchDomainRequestRequestTypeDef",
+    {
+        "ElasticsearchVersion": str,
+        "ElasticsearchClusterConfig": "ElasticsearchClusterConfigTypeDef",
+        "EBSOptions": "EBSOptionsTypeDef",
+        "AccessPolicies": str,
+        "SnapshotOptions": "SnapshotOptionsTypeDef",
+        "VPCOptions": "VPCOptionsTypeDef",
+        "CognitoOptions": "CognitoOptionsTypeDef",
+        "EncryptionAtRestOptions": "EncryptionAtRestOptionsTypeDef",
+        "NodeToNodeEncryptionOptions": "NodeToNodeEncryptionOptionsTypeDef",
+        "AdvancedOptions": Dict[str, str],
+        "LogPublishingOptions": Dict[LogTypeType, "LogPublishingOptionTypeDef"],
+        "DomainEndpointOptions": "DomainEndpointOptionsTypeDef",
+        "AdvancedSecurityOptions": "AdvancedSecurityOptionsInputTypeDef",
+        "AutoTuneOptions": "AutoTuneOptionsInputTypeDef",
+        "TagList": List["TagTypeDef"],
+    },
+    total=False,
+)
+
+
+class CreateElasticsearchDomainRequestRequestTypeDef(
+    _RequiredCreateElasticsearchDomainRequestRequestTypeDef,
+    _OptionalCreateElasticsearchDomainRequestRequestTypeDef,
+):
+    pass
+
+
 CreateElasticsearchDomainResponseTypeDef = TypedDict(
     "CreateElasticsearchDomainResponseTypeDef",
     {
         "DomainStatus": "ElasticsearchDomainStatusTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+CreateOutboundCrossClusterSearchConnectionRequestRequestTypeDef = TypedDict(
+    "CreateOutboundCrossClusterSearchConnectionRequestRequestTypeDef",
+    {
+        "SourceDomainInfo": "DomainInformationTypeDef",
+        "DestinationDomainInfo": "DomainInformationTypeDef",
+        "ConnectionAlias": str,
     },
-    total=False,
 )
 
 CreateOutboundCrossClusterSearchConnectionResponseTypeDef = TypedDict(
@@ -377,63 +490,152 @@ CreateOutboundCrossClusterSearchConnectionResponseTypeDef = TypedDict(
         "ConnectionAlias": str,
         "ConnectionStatus": "OutboundCrossClusterSearchConnectionStatusTypeDef",
         "CrossClusterSearchConnectionId": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredCreatePackageRequestRequestTypeDef = TypedDict(
+    "_RequiredCreatePackageRequestRequestTypeDef",
+    {
+        "PackageName": str,
+        "PackageType": Literal["TXT-DICTIONARY"],
+        "PackageSource": "PackageSourceTypeDef",
+    },
+)
+_OptionalCreatePackageRequestRequestTypeDef = TypedDict(
+    "_OptionalCreatePackageRequestRequestTypeDef",
+    {
+        "PackageDescription": str,
     },
     total=False,
 )
 
+
+class CreatePackageRequestRequestTypeDef(
+    _RequiredCreatePackageRequestRequestTypeDef, _OptionalCreatePackageRequestRequestTypeDef
+):
+    pass
+
+
 CreatePackageResponseTypeDef = TypedDict(
     "CreatePackageResponseTypeDef",
     {
         "PackageDetails": "PackageDetailsTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+DeleteElasticsearchDomainRequestRequestTypeDef = TypedDict(
+    "DeleteElasticsearchDomainRequestRequestTypeDef",
+    {
+        "DomainName": str,
     },
-    total=False,
 )
 
 DeleteElasticsearchDomainResponseTypeDef = TypedDict(
     "DeleteElasticsearchDomainResponseTypeDef",
     {
         "DomainStatus": "ElasticsearchDomainStatusTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+DeleteInboundCrossClusterSearchConnectionRequestRequestTypeDef = TypedDict(
+    "DeleteInboundCrossClusterSearchConnectionRequestRequestTypeDef",
+    {
+        "CrossClusterSearchConnectionId": str,
     },
-    total=False,
 )
 
 DeleteInboundCrossClusterSearchConnectionResponseTypeDef = TypedDict(
     "DeleteInboundCrossClusterSearchConnectionResponseTypeDef",
     {
         "CrossClusterSearchConnection": "InboundCrossClusterSearchConnectionTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+DeleteOutboundCrossClusterSearchConnectionRequestRequestTypeDef = TypedDict(
+    "DeleteOutboundCrossClusterSearchConnectionRequestRequestTypeDef",
+    {
+        "CrossClusterSearchConnectionId": str,
     },
-    total=False,
 )
 
 DeleteOutboundCrossClusterSearchConnectionResponseTypeDef = TypedDict(
     "DeleteOutboundCrossClusterSearchConnectionResponseTypeDef",
     {
         "CrossClusterSearchConnection": "OutboundCrossClusterSearchConnectionTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+DeletePackageRequestRequestTypeDef = TypedDict(
+    "DeletePackageRequestRequestTypeDef",
+    {
+        "PackageID": str,
     },
-    total=False,
 )
 
 DeletePackageResponseTypeDef = TypedDict(
     "DeletePackageResponseTypeDef",
     {
         "PackageDetails": "PackageDetailsTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredDescribeDomainAutoTunesRequestRequestTypeDef = TypedDict(
+    "_RequiredDescribeDomainAutoTunesRequestRequestTypeDef",
+    {
+        "DomainName": str,
+    },
+)
+_OptionalDescribeDomainAutoTunesRequestRequestTypeDef = TypedDict(
+    "_OptionalDescribeDomainAutoTunesRequestRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
     },
     total=False,
 )
 
+
+class DescribeDomainAutoTunesRequestRequestTypeDef(
+    _RequiredDescribeDomainAutoTunesRequestRequestTypeDef,
+    _OptionalDescribeDomainAutoTunesRequestRequestTypeDef,
+):
+    pass
+
+
 DescribeDomainAutoTunesResponseTypeDef = TypedDict(
     "DescribeDomainAutoTunesResponseTypeDef",
     {
         "AutoTunes": List["AutoTuneTypeDef"],
         "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+DescribeElasticsearchDomainConfigRequestRequestTypeDef = TypedDict(
+    "DescribeElasticsearchDomainConfigRequestRequestTypeDef",
+    {
+        "DomainName": str,
     },
-    total=False,
 )
 
 DescribeElasticsearchDomainConfigResponseTypeDef = TypedDict(
     "DescribeElasticsearchDomainConfigResponseTypeDef",
     {
         "DomainConfig": "ElasticsearchDomainConfigTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+DescribeElasticsearchDomainRequestRequestTypeDef = TypedDict(
+    "DescribeElasticsearchDomainRequestRequestTypeDef",
+    {
+        "DomainName": str,
     },
 )
 
@@ -441,6 +643,14 @@ DescribeElasticsearchDomainResponseTypeDef = TypedDict(
     "DescribeElasticsearchDomainResponseTypeDef",
     {
         "DomainStatus": "ElasticsearchDomainStatusTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+DescribeElasticsearchDomainsRequestRequestTypeDef = TypedDict(
+    "DescribeElasticsearchDomainsRequestRequestTypeDef",
+    {
+        "DomainNames": List[str],
     },
 )
 
@@ -448,13 +658,47 @@ DescribeElasticsearchDomainsResponseTypeDef = TypedDict(
     "DescribeElasticsearchDomainsResponseTypeDef",
     {
         "DomainStatusList": List["ElasticsearchDomainStatusTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
+_RequiredDescribeElasticsearchInstanceTypeLimitsRequestRequestTypeDef = TypedDict(
+    "_RequiredDescribeElasticsearchInstanceTypeLimitsRequestRequestTypeDef",
+    {
+        "InstanceType": ESPartitionInstanceTypeType,
+        "ElasticsearchVersion": str,
+    },
+)
+_OptionalDescribeElasticsearchInstanceTypeLimitsRequestRequestTypeDef = TypedDict(
+    "_OptionalDescribeElasticsearchInstanceTypeLimitsRequestRequestTypeDef",
+    {
+        "DomainName": str,
+    },
+    total=False,
+)
+
+
+class DescribeElasticsearchInstanceTypeLimitsRequestRequestTypeDef(
+    _RequiredDescribeElasticsearchInstanceTypeLimitsRequestRequestTypeDef,
+    _OptionalDescribeElasticsearchInstanceTypeLimitsRequestRequestTypeDef,
+):
+    pass
+
+
 DescribeElasticsearchInstanceTypeLimitsResponseTypeDef = TypedDict(
     "DescribeElasticsearchInstanceTypeLimitsResponseTypeDef",
     {
         "LimitsByRole": Dict[str, "LimitsTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+DescribeInboundCrossClusterSearchConnectionsRequestRequestTypeDef = TypedDict(
+    "DescribeInboundCrossClusterSearchConnectionsRequestRequestTypeDef",
+    {
+        "Filters": List["FilterTypeDef"],
+        "MaxResults": int,
+        "NextToken": str,
     },
     total=False,
 )
@@ -464,6 +708,16 @@ DescribeInboundCrossClusterSearchConnectionsResponseTypeDef = TypedDict(
     {
         "CrossClusterSearchConnections": List["InboundCrossClusterSearchConnectionTypeDef"],
         "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+DescribeOutboundCrossClusterSearchConnectionsRequestRequestTypeDef = TypedDict(
+    "DescribeOutboundCrossClusterSearchConnectionsRequestRequestTypeDef",
+    {
+        "Filters": List["FilterTypeDef"],
+        "MaxResults": int,
+        "NextToken": str,
     },
     total=False,
 )
@@ -473,8 +727,8 @@ DescribeOutboundCrossClusterSearchConnectionsResponseTypeDef = TypedDict(
     {
         "CrossClusterSearchConnections": List["OutboundCrossClusterSearchConnectionTypeDef"],
         "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 DescribePackagesFilterTypeDef = TypedDict(
@@ -486,11 +740,31 @@ DescribePackagesFilterTypeDef = TypedDict(
     total=False,
 )
 
+DescribePackagesRequestRequestTypeDef = TypedDict(
+    "DescribePackagesRequestRequestTypeDef",
+    {
+        "Filters": List["DescribePackagesFilterTypeDef"],
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
 DescribePackagesResponseTypeDef = TypedDict(
     "DescribePackagesResponseTypeDef",
     {
         "PackageDetailsList": List["PackageDetailsTypeDef"],
         "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+DescribeReservedElasticsearchInstanceOfferingsRequestRequestTypeDef = TypedDict(
+    "DescribeReservedElasticsearchInstanceOfferingsRequestRequestTypeDef",
+    {
+        "ReservedElasticsearchInstanceOfferingId": str,
+        "MaxResults": int,
+        "NextToken": str,
     },
     total=False,
 )
@@ -502,6 +776,16 @@ DescribeReservedElasticsearchInstanceOfferingsResponseTypeDef = TypedDict(
         "ReservedElasticsearchInstanceOfferings": List[
             "ReservedElasticsearchInstanceOfferingTypeDef"
         ],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+DescribeReservedElasticsearchInstancesRequestRequestTypeDef = TypedDict(
+    "DescribeReservedElasticsearchInstancesRequestRequestTypeDef",
+    {
+        "ReservedElasticsearchInstanceId": str,
+        "MaxResults": int,
+        "NextToken": str,
     },
     total=False,
 )
@@ -511,16 +795,24 @@ DescribeReservedElasticsearchInstancesResponseTypeDef = TypedDict(
     {
         "NextToken": str,
         "ReservedElasticsearchInstances": List["ReservedElasticsearchInstanceTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+DissociatePackageRequestRequestTypeDef = TypedDict(
+    "DissociatePackageRequestRequestTypeDef",
+    {
+        "PackageID": str,
+        "DomainName": str,
     },
-    total=False,
 )
 
 DissociatePackageResponseTypeDef = TypedDict(
     "DissociatePackageResponseTypeDef",
     {
         "DomainPackageDetails": "DomainPackageDetailsTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 DomainEndpointOptionsStatusTypeDef = TypedDict(
@@ -750,31 +1042,91 @@ FilterTypeDef = TypedDict(
     total=False,
 )
 
+GetCompatibleElasticsearchVersionsRequestRequestTypeDef = TypedDict(
+    "GetCompatibleElasticsearchVersionsRequestRequestTypeDef",
+    {
+        "DomainName": str,
+    },
+    total=False,
+)
+
 GetCompatibleElasticsearchVersionsResponseTypeDef = TypedDict(
     "GetCompatibleElasticsearchVersionsResponseTypeDef",
     {
         "CompatibleElasticsearchVersions": List["CompatibleVersionsMapTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredGetPackageVersionHistoryRequestRequestTypeDef = TypedDict(
+    "_RequiredGetPackageVersionHistoryRequestRequestTypeDef",
+    {
+        "PackageID": str,
+    },
+)
+_OptionalGetPackageVersionHistoryRequestRequestTypeDef = TypedDict(
+    "_OptionalGetPackageVersionHistoryRequestRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
     },
     total=False,
 )
 
+
+class GetPackageVersionHistoryRequestRequestTypeDef(
+    _RequiredGetPackageVersionHistoryRequestRequestTypeDef,
+    _OptionalGetPackageVersionHistoryRequestRequestTypeDef,
+):
+    pass
+
+
 GetPackageVersionHistoryResponseTypeDef = TypedDict(
     "GetPackageVersionHistoryResponseTypeDef",
     {
         "PackageID": str,
         "PackageVersionHistoryList": List["PackageVersionHistoryTypeDef"],
         "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredGetUpgradeHistoryRequestRequestTypeDef = TypedDict(
+    "_RequiredGetUpgradeHistoryRequestRequestTypeDef",
+    {
+        "DomainName": str,
+    },
+)
+_OptionalGetUpgradeHistoryRequestRequestTypeDef = TypedDict(
+    "_OptionalGetUpgradeHistoryRequestRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
     },
     total=False,
 )
 
+
+class GetUpgradeHistoryRequestRequestTypeDef(
+    _RequiredGetUpgradeHistoryRequestRequestTypeDef, _OptionalGetUpgradeHistoryRequestRequestTypeDef
+):
+    pass
+
+
 GetUpgradeHistoryResponseTypeDef = TypedDict(
     "GetUpgradeHistoryResponseTypeDef",
     {
         "UpgradeHistories": List["UpgradeHistoryTypeDef"],
         "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+GetUpgradeStatusRequestRequestTypeDef = TypedDict(
+    "GetUpgradeStatusRequestRequestTypeDef",
+    {
+        "DomainName": str,
     },
-    total=False,
 )
 
 GetUpgradeStatusResponseTypeDef = TypedDict(
@@ -783,8 +1135,8 @@ GetUpgradeStatusResponseTypeDef = TypedDict(
         "UpgradeStep": UpgradeStepType,
         "StepStatus": UpgradeStatusType,
         "UpgradeName": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 InboundCrossClusterSearchConnectionStatusTypeDef = TypedDict(
@@ -838,24 +1190,80 @@ ListDomainNamesResponseTypeDef = TypedDict(
     "ListDomainNamesResponseTypeDef",
     {
         "DomainNames": List["DomainInfoTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredListDomainsForPackageRequestRequestTypeDef = TypedDict(
+    "_RequiredListDomainsForPackageRequestRequestTypeDef",
+    {
+        "PackageID": str,
+    },
+)
+_OptionalListDomainsForPackageRequestRequestTypeDef = TypedDict(
+    "_OptionalListDomainsForPackageRequestRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
     },
     total=False,
 )
 
+
+class ListDomainsForPackageRequestRequestTypeDef(
+    _RequiredListDomainsForPackageRequestRequestTypeDef,
+    _OptionalListDomainsForPackageRequestRequestTypeDef,
+):
+    pass
+
+
 ListDomainsForPackageResponseTypeDef = TypedDict(
     "ListDomainsForPackageResponseTypeDef",
     {
         "DomainPackageDetailsList": List["DomainPackageDetailsTypeDef"],
         "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredListElasticsearchInstanceTypesRequestRequestTypeDef = TypedDict(
+    "_RequiredListElasticsearchInstanceTypesRequestRequestTypeDef",
+    {
+        "ElasticsearchVersion": str,
+    },
+)
+_OptionalListElasticsearchInstanceTypesRequestRequestTypeDef = TypedDict(
+    "_OptionalListElasticsearchInstanceTypesRequestRequestTypeDef",
+    {
+        "DomainName": str,
+        "MaxResults": int,
+        "NextToken": str,
     },
     total=False,
 )
 
+
+class ListElasticsearchInstanceTypesRequestRequestTypeDef(
+    _RequiredListElasticsearchInstanceTypesRequestRequestTypeDef,
+    _OptionalListElasticsearchInstanceTypesRequestRequestTypeDef,
+):
+    pass
+
+
 ListElasticsearchInstanceTypesResponseTypeDef = TypedDict(
     "ListElasticsearchInstanceTypesResponseTypeDef",
     {
         "ElasticsearchInstanceTypes": List[ESPartitionInstanceTypeType],
         "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+ListElasticsearchVersionsRequestRequestTypeDef = TypedDict(
+    "ListElasticsearchVersionsRequestRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
     },
     total=False,
 )
@@ -865,25 +1273,55 @@ ListElasticsearchVersionsResponseTypeDef = TypedDict(
     {
         "ElasticsearchVersions": List[str],
         "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredListPackagesForDomainRequestRequestTypeDef = TypedDict(
+    "_RequiredListPackagesForDomainRequestRequestTypeDef",
+    {
+        "DomainName": str,
+    },
+)
+_OptionalListPackagesForDomainRequestRequestTypeDef = TypedDict(
+    "_OptionalListPackagesForDomainRequestRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
     },
     total=False,
 )
 
+
+class ListPackagesForDomainRequestRequestTypeDef(
+    _RequiredListPackagesForDomainRequestRequestTypeDef,
+    _OptionalListPackagesForDomainRequestRequestTypeDef,
+):
+    pass
+
+
 ListPackagesForDomainResponseTypeDef = TypedDict(
     "ListPackagesForDomainResponseTypeDef",
     {
         "DomainPackageDetailsList": List["DomainPackageDetailsTypeDef"],
         "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+ListTagsRequestRequestTypeDef = TypedDict(
+    "ListTagsRequestRequestTypeDef",
+    {
+        "ARN": str,
     },
-    total=False,
 )
 
 ListTagsResponseTypeDef = TypedDict(
     "ListTagsResponseTypeDef",
     {
         "TagList": List["TagTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 LogPublishingOptionTypeDef = TypedDict(
@@ -1018,13 +1456,36 @@ PaginatorConfigTypeDef = TypedDict(
     total=False,
 )
 
+_RequiredPurchaseReservedElasticsearchInstanceOfferingRequestRequestTypeDef = TypedDict(
+    "_RequiredPurchaseReservedElasticsearchInstanceOfferingRequestRequestTypeDef",
+    {
+        "ReservedElasticsearchInstanceOfferingId": str,
+        "ReservationName": str,
+    },
+)
+_OptionalPurchaseReservedElasticsearchInstanceOfferingRequestRequestTypeDef = TypedDict(
+    "_OptionalPurchaseReservedElasticsearchInstanceOfferingRequestRequestTypeDef",
+    {
+        "InstanceCount": int,
+    },
+    total=False,
+)
+
+
+class PurchaseReservedElasticsearchInstanceOfferingRequestRequestTypeDef(
+    _RequiredPurchaseReservedElasticsearchInstanceOfferingRequestRequestTypeDef,
+    _OptionalPurchaseReservedElasticsearchInstanceOfferingRequestRequestTypeDef,
+):
+    pass
+
+
 PurchaseReservedElasticsearchInstanceOfferingResponseTypeDef = TypedDict(
     "PurchaseReservedElasticsearchInstanceOfferingResponseTypeDef",
     {
         "ReservedElasticsearchInstanceId": str,
         "ReservationName": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 RecurringChargeTypeDef = TypedDict(
@@ -1036,12 +1497,27 @@ RecurringChargeTypeDef = TypedDict(
     total=False,
 )
 
+RejectInboundCrossClusterSearchConnectionRequestRequestTypeDef = TypedDict(
+    "RejectInboundCrossClusterSearchConnectionRequestRequestTypeDef",
+    {
+        "CrossClusterSearchConnectionId": str,
+    },
+)
+
 RejectInboundCrossClusterSearchConnectionResponseTypeDef = TypedDict(
     "RejectInboundCrossClusterSearchConnectionResponseTypeDef",
     {
         "CrossClusterSearchConnection": "InboundCrossClusterSearchConnectionTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+RemoveTagsRequestRequestTypeDef = TypedDict(
+    "RemoveTagsRequestRequestTypeDef",
+    {
+        "ARN": str,
+        "TagKeys": List[str],
     },
-    total=False,
 )
 
 ReservedElasticsearchInstanceOfferingTypeDef = TypedDict(
@@ -1120,8 +1596,8 @@ SAMLOptionsOutputTypeDef = TypedDict(
         "SubjectKey": str,
         "RolesKey": str,
         "SessionTimeoutMinutes": int,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
+    total=False,
 )
 
 ScheduledAutoTuneDetailsTypeDef = TypedDict(
@@ -1166,12 +1642,19 @@ SnapshotOptionsTypeDef = TypedDict(
     total=False,
 )
 
+StartElasticsearchServiceSoftwareUpdateRequestRequestTypeDef = TypedDict(
+    "StartElasticsearchServiceSoftwareUpdateRequestRequestTypeDef",
+    {
+        "DomainName": str,
+    },
+)
+
 StartElasticsearchServiceSoftwareUpdateResponseTypeDef = TypedDict(
     "StartElasticsearchServiceSoftwareUpdateResponseTypeDef",
     {
         "ServiceSoftwareOptions": "ServiceSoftwareOptionsTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 StorageTypeLimitTypeDef = TypedDict(
@@ -1201,29 +1684,110 @@ TagTypeDef = TypedDict(
     },
 )
 
+_RequiredUpdateElasticsearchDomainConfigRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateElasticsearchDomainConfigRequestRequestTypeDef",
+    {
+        "DomainName": str,
+    },
+)
+_OptionalUpdateElasticsearchDomainConfigRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateElasticsearchDomainConfigRequestRequestTypeDef",
+    {
+        "ElasticsearchClusterConfig": "ElasticsearchClusterConfigTypeDef",
+        "EBSOptions": "EBSOptionsTypeDef",
+        "SnapshotOptions": "SnapshotOptionsTypeDef",
+        "VPCOptions": "VPCOptionsTypeDef",
+        "CognitoOptions": "CognitoOptionsTypeDef",
+        "AdvancedOptions": Dict[str, str],
+        "AccessPolicies": str,
+        "LogPublishingOptions": Dict[LogTypeType, "LogPublishingOptionTypeDef"],
+        "DomainEndpointOptions": "DomainEndpointOptionsTypeDef",
+        "AdvancedSecurityOptions": "AdvancedSecurityOptionsInputTypeDef",
+        "NodeToNodeEncryptionOptions": "NodeToNodeEncryptionOptionsTypeDef",
+        "EncryptionAtRestOptions": "EncryptionAtRestOptionsTypeDef",
+        "AutoTuneOptions": "AutoTuneOptionsTypeDef",
+    },
+    total=False,
+)
+
+
+class UpdateElasticsearchDomainConfigRequestRequestTypeDef(
+    _RequiredUpdateElasticsearchDomainConfigRequestRequestTypeDef,
+    _OptionalUpdateElasticsearchDomainConfigRequestRequestTypeDef,
+):
+    pass
+
+
 UpdateElasticsearchDomainConfigResponseTypeDef = TypedDict(
     "UpdateElasticsearchDomainConfigResponseTypeDef",
     {
         "DomainConfig": "ElasticsearchDomainConfigTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
+_RequiredUpdatePackageRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdatePackageRequestRequestTypeDef",
+    {
+        "PackageID": str,
+        "PackageSource": "PackageSourceTypeDef",
+    },
+)
+_OptionalUpdatePackageRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdatePackageRequestRequestTypeDef",
+    {
+        "PackageDescription": str,
+        "CommitMessage": str,
+    },
+    total=False,
+)
+
+
+class UpdatePackageRequestRequestTypeDef(
+    _RequiredUpdatePackageRequestRequestTypeDef, _OptionalUpdatePackageRequestRequestTypeDef
+):
+    pass
+
+
 UpdatePackageResponseTypeDef = TypedDict(
     "UpdatePackageResponseTypeDef",
     {
         "PackageDetails": "PackageDetailsTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredUpgradeElasticsearchDomainRequestRequestTypeDef = TypedDict(
+    "_RequiredUpgradeElasticsearchDomainRequestRequestTypeDef",
+    {
+        "DomainName": str,
+        "TargetVersion": str,
+    },
+)
+_OptionalUpgradeElasticsearchDomainRequestRequestTypeDef = TypedDict(
+    "_OptionalUpgradeElasticsearchDomainRequestRequestTypeDef",
+    {
+        "PerformCheckOnly": bool,
     },
     total=False,
 )
 
+
+class UpgradeElasticsearchDomainRequestRequestTypeDef(
+    _RequiredUpgradeElasticsearchDomainRequestRequestTypeDef,
+    _OptionalUpgradeElasticsearchDomainRequestRequestTypeDef,
+):
+    pass
+
+
 UpgradeElasticsearchDomainResponseTypeDef = TypedDict(
     "UpgradeElasticsearchDomainResponseTypeDef",
     {
         "DomainName": str,
         "TargetVersion": str,
         "PerformCheckOnly": bool,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 UpgradeHistoryTypeDef = TypedDict(
